optmanage: A library to create flexible option managers.
========================================================

.. image:: https://img.shields.io/badge/python-3.10+-green.svg
    :target: https://docs.python.org/3.10/
    :alt: Python versions

.. image:: https://img.shields.io/pypi/v/optmanage.svg
    :target: https://pypi.python.org/pypi/optmanage/
    :alt: PyPI version

.. image:: https://img.shields.io/pypi/status/optmanage.svg
    :target: https://pypi.python.org/pypi/optmanage/
    :alt: PyPI status

.. image:: http://www.mypy-lang.org/static/mypy_badge.svg
    :target: https://github.com/python/mypy
    :alt: Checked with Mypy

.. image:: https://readthedocs.org/projects/optmanage/badge/?version=latest
    :target: https://optmanage.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

.. image:: https://github.com/hashberg-io/optmanage/actions/workflows/python-pytest.yml/badge.svg
    :target: https://github.com/hashberg-io/optmanage/actions/workflows/python-pytest.yml
    :alt: Python package status

.. image:: https://img.shields.io/badge/readme%20style-standard-brightgreen.svg?style=flat-square
    :target: https://github.com/RichardLitt/standard-readme
    :alt: standard-readme compliant


A library to create flexible option managers.

.. contents::


Install
-------

This project is currently in private development. At present, you should clone the repository and install it locally as follows:

.. code-block:: console

    $ pip install --upgrade .


One the package is published, you will be able to install the latest release from `PyPI <https://pypi.org/project/optmanage/>`_ as follows:

.. code-block:: console

    $ pip install --upgrade optmanage


Usage
-----

This project is currently in private development. For usage examples, refer to the ``notebooks`` folder.



API
---

At present, documentation is built locally by the script ``docs/make-api-clean-html.bat``, and subsequently accessed from ``docs/_build/html/index.html``.

One the package is published, the full API documentation will be available at https://optmanage.readthedocs.io/


Contributing
------------

This project is currently in private development. Public contribution guidelines are available at `<CONTRIBUTING.md>`_.


License
-------

`LGPL © Hashberg Ltd. <LICENSE>`_
